.. _party_module:

:mod:`kazoo.recipe.party`
-------------------------

.. automodule:: kazoo.recipe.party

Public API
++++++++++

    .. autoclass:: Party
        :members:
        :inherited-members:

        .. automethod:: __init__
        .. automethod:: __iter__
        .. automethod:: __len__

    .. autoclass:: ShallowParty
        :members:
        :inherited-members:

        .. automethod:: __init__
        .. automethod:: __iter__
        .. automethod:: __len__
